==> substance_4.1.orig.tar.gz: substance-4.1.orig/src/test/samples/lafwidget/clientprop/ComboBoxAutoCompletionMatcher.java <==
/*
 * Copyright (c) 2005-2007 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package test.samples.lafwidget.clientprop;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.*;

import org.jvnet.lafwidget.LafWidget;
import org.jvnet.lafwidget.combo.AutoCompletionMatcher;
import org.jvnet.substance.SubstanceLookAndFeel;

/**
 * Test application that shows the use of the
 * {@link LafWidget#COMBO_BOX_USE_MODEL_ONLY} client property.
 * 
 * @author Kirill Grouchnikov
 * @see LafWidget#COMBO_BOX_USE_MODEL_ONLY
 */
public class ComboBoxAutoCompletionMatcher extends JFrame {
	/**
	 * Case sensitive matcher for combobox auto-completion.
	 * 
	 * @author Kirill Grouchnikov
	 */
	protected static class CaseSensitiveMatcher implements
			AutoCompletionMatcher {
		public Object getFirstMatching(ComboBoxModel model, String pattern) {
			Object selectedItem = model.getSelectedItem();
			// only search for a different item if the currently
			// selected does not match
			if ((selectedItem != null)
					&& selectedItem.toString().startsWith(pattern)) {
				return selectedItem;
			} else {
				// iterate over all items
				for (int i = 0, n = model.getSize(); i < n; i++) {
					Object currentItem = model.getElementAt(i);
					// current item starts with the pattern?
					if ((currentItem != null)
							&& currentItem.toString().startsWith(pattern)) {
						return currentItem;
					}
				}
			}
			// no item starts with the pattern => return null
			return null;
		}
	}

	/**
	 * Creates the main frame for <code>this</code> sample.
	 */
	public ComboBoxAutoCompletionMatcher() {
		super("Combobox auto-completion custom matcher");

		this.setLayout(new BorderLayout());

		final JComboBox cb = new JComboBox(new Object[] { "Ester", "Jordi",
				"Jordina", "Jorge", "sergi" });
		cb.setEditable(true);

		JPanel main = new JPanel(new FlowLayout(FlowLayout.CENTER));
		this.add(main, BorderLayout.CENTER);
		main.add(cb);

		JPanel controls = new JPanel(new FlowLayout(FlowLayout.RIGHT));

		final JCheckBox caseSensitiveAutoCompletion = new JCheckBox(
				"Use case-sensitive auto-completion");
		caseSensitiveAutoCompletion.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				cb
						.putClientProperty(
								LafWidget.COMBO_BOX_AUTOCOMPLETION_MATCHER,
								caseSensitiveAutoCompletion.isSelected() ? new CaseSensitiveMatcher()
										: null);
			}
		});

		controls.add(caseSensitiveAutoCompletion);
		this.add(controls, BorderLayout.SOUTH);

		this.setSize(400, 200);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	/**
	 * The main method for <code>this</code> sample. The arguments are
	 * ignored.
	 * 
	 * @param args
	 *            Ignored.
	 * @throws Exception
	 *             If some exception occured. Note that there is no special
	 *             treatment of exception conditions in <code>this</code>
	 *             sample code.
	 */
	public static void main(String[] args) throws Exception {
		UIManager.setLookAndFeel(new SubstanceLookAndFeel());
		JFrame.setDefaultLookAndFeelDecorated(true);
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new ComboBoxAutoCompletionMatcher().setVisible(true);
			}
		});
	}
}

==> substance_4.3.11.orig.tar.gz: substance-4.3.11.orig/src/test/samples/lafwidget/clientprop/ComboBoxAutoCompletionMatcher.java <==
/*
 * Copyright (c) 2005-2008 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * 
 *  o Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *     
 *  o Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation 
 *    and/or other materials provided with the distribution. 
 *     
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of 
 *    its contributors may be used to endorse or promote products derived 
 *    from this software without specific prior written permission. 
 *     
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR 
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, 
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; 
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE 
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
 */
package test.samples.lafwidget.clientprop;

import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.*;

import org.jvnet.lafwidget.LafWidget;
import org.jvnet.lafwidget.combo.AutoCompletionMatcher;
import org.jvnet.substance.skin.SubstanceBusinessBlackSteelLookAndFeel;

/**
 * Test application that shows the use of the
 * {@link LafWidget#COMBO_BOX_USE_MODEL_ONLY} client property.
 * 
 * @author Kirill Grouchnikov
 * @see LafWidget#COMBO_BOX_USE_MODEL_ONLY
 */
public class ComboBoxAutoCompletionMatcher extends JFrame {
	/**
	 * Case sensitive matcher for combobox auto-completion.
	 * 
	 * @author Kirill Grouchnikov
	 */
	protected static class CaseSensitiveMatcher implements
			AutoCompletionMatcher {
		public Object getFirstMatching(ComboBoxModel model, String pattern) {
			Object selectedItem = model.getSelectedItem();
			// only search for a different item if the currently
			// selected does not match
			if ((selectedItem != null)
					&& selectedItem.toString().startsWith(pattern)) {
				return selectedItem;
			} else {
				// iterate over all items
				for (int i = 0, n = model.getSize(); i < n; i++) {
					Object currentItem = model.getElementAt(i);
					// current item starts with the pattern?
					if ((currentItem != null)
							&& currentItem.toString().startsWith(pattern)) {
						return currentItem;
					}
				}
			}
			// no item starts with the pattern => return null
			return null;
		}
	}

	/**
	 * Creates the main frame for <code>this</code> sample.
	 */
	public ComboBoxAutoCompletionMatcher() {
		super("Combobox auto-completion custom matcher");

		this.setLayout(new BorderLayout());

		final JComboBox cb = new JComboBox(new Object[] { "Ester", "Jordi",
				"Jordina", "Jorge", "sergi" });
		cb.setEditable(true);

		JPanel main = new JPanel(new FlowLayout(FlowLayout.CENTER));
		this.add(main, BorderLayout.CENTER);
		main.add(cb);

		JPanel controls = new JPanel(new FlowLayout(FlowLayout.RIGHT));

		final JCheckBox caseSensitiveAutoCompletion = new JCheckBox(
				"Use case-sensitive auto-completion");
		caseSensitiveAutoCompletion.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				cb
						.putClientProperty(
								LafWidget.COMBO_BOX_AUTOCOMPLETION_MATCHER,
								caseSensitiveAutoCompletion.isSelected() ? new CaseSensitiveMatcher()
										: null);
			}
		});

		controls.add(caseSensitiveAutoCompletion);
		this.add(controls, BorderLayout.SOUTH);

		this.setSize(400, 200);
		this.setLocationRelativeTo(null);
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
	}

	/**
	 * The main method for <code>this</code> sample. The arguments are
	 * ignored.
	 * 
	 * @param args
	 *            Ignored.
	 * @throws Exception
	 *             If some exception occured. Note that there is no special
	 *             treatment of exception conditions in <code>this</code>
	 *             sample code.
	 */
	public static void main(String[] args) throws Exception {
		UIManager.setLookAndFeel(new SubstanceBusinessBlackSteelLookAndFeel());
		JFrame.setDefaultLookAndFeelDecorated(true);
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				new ComboBoxAutoCompletionMatcher().setVisible(true);
			}
		});
	}
}
